package
Version:
v0.0.0-...-c0326d0
Opens a new window with list of versions in this module.
Published: Mar 4, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Set is a generic set data structure.
New creates a new set from the given values.
func (s Set[V]) Delete(vs ...V) Set[V]
Delete removes the given values from the set.
Has returns true if the set contains the given value.
func (s Set[V]) Insert(vs ...V) Set[V]
Insert adds the given values to the set.
Len returns the length of the set.
Values returns an iterator over all values in the set.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.